#include <avr/io.h>
#include "NES_Remote.h"

void initPins();
char getButtons();
void delay();
char getWhiskers();

/*
 * NES Interface:
 * There are three pins of use on the NES: 
 * data, latch, and clk. When we want to 
 * read the 8 bits off the NES remote, send
 * a latch (latch -> high, then latch -> low).
 * upon doing this, the first bit of data is
 * on the NES's data line. Grab it. Then
 * clk the next bit (CLK -> high, CLK -> low).
 * The next bit is available, grab it.
 * Continue this until all 8 bits of data are
 * gathered. Here is the order of the bits:
 *
 * A B select start up down left right
 *
 * In these data bits, if the value of a bit
 * is '0', it means the button was pressed.
 * a '1' means the button was not pressed.
 */

#define LATCH 0x02
#define CLK 0x04
#define DATA 0x01

void initNes()
{
	DDRA = DDRA + 0x06;	
}

char getButtons()
{

	char buttons = 0x00;
	
	char state = PINA & 0xF8;
	PORTA = state;		

    //Latch clocks data into the NES' shift register
	delay();
	PORTA = state|LATCH;
	delay();
    PORTA = state;
	
	int key = 0;

	while(key<8)
	{
		buttons = buttons<<1;
		buttons |= PINA & DATA;

		key=key+1;
		PORTA=state|CLK;
		delay();
		PORTA=state;
		delay();
	}
    
 	return ~buttons;
}


void delay()
{
	int num = 2000;
	while(num>1)
	{
		num=num-1;
	}
}




